class ExecutionEvent {
  final String promptId;
  final int timestamp;
  final String? node;
  final List<Map<String, dynamic>>? outputImages;
  final Map<String, dynamic>? extra;

  const ExecutionEvent({
    required this.promptId,
    required this.timestamp,
    this.node,
    this.outputImages,
    this.extra,
  });

  factory ExecutionEvent.fromJson(Map<String, dynamic> json) {
    // Note: This factory is not directly used by the handler,
    // but kept for potential future use or consistency.
    // The handler now constructs the event directly.
    return ExecutionEvent(
      promptId: json['prompt_id'] as String,
      timestamp: json['timestamp'] as int,
      node: json['node'] as String?,
      // Parsing logic moved to the handler for direct use.
      // outputImages: (json['output']?['images'] as List<dynamic>?)
      //     ?.map((e) => e as Map<String, dynamic>)
      //     .toList(),
      extra: json['extra'] as Map<String, dynamic>?,
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'prompt_id': promptId,
      'timestamp': timestamp,
      'node': node,
      'outputImages': outputImages, // Added for completeness
      'extra': extra,
    };
  }
}
